@@ -11,35 +11,30 @@
 
 #include <wayland-server-core.h>
 #include <wayland-server-protocol.h>
-#include <wlr/interfaces/wlr_input_device.h>
 #include <wlr/interfaces/wlr_pointer.h>
 #include <wlr/interfaces/wlr_output.h>
 
 struct wlr_virtual_pointer_manager_v1 {
 	struct wl_global *global;
-	struct wl_list virtual_pointers; // struct wlr_virtual_pointer_v1*
+	struct wl_list virtual_pointers; // wlr_virtual_pointer_v1.link
 
 	struct wl_listener display_destroy;
 
 	struct {
-		struct wl_signal new_virtual_pointer; // struct wlr_virtual_pointer_v1_new_pointer_event*
+		struct wl_signal new_virtual_pointer; // struct wlr_virtual_pointer_v1_new_pointer_event *
 		struct wl_signal destroy;
 	} events;
 };
 
 struct wlr_virtual_pointer_v1 {
-	struct wlr_input_device input_device;
+	struct wlr_pointer pointer;
 	struct wl_resource *resource;
 	/* Vertical and horizontal */
-	struct wlr_event_pointer_axis axis_event[2];
+	struct wlr_pointer_axis_event axis_event[2];
 	enum wl_pointer_axis axis;
 	bool axis_valid[2];
 
-	struct wl_list link;
-
-	struct {
-		struct wl_signal destroy; // struct wlr_virtual_pointer_v1*
-	} events;
+	struct wl_list link; // wlr_virtual_pointer_manager_v1.virtual_pointers
 };
 
 struct wlr_virtual_pointer_v1_new_pointer_event {
